==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>创建电子表格</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>创建一个新的电子表格</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>底端对齐</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>底端对齐所选单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>居中对齐</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>居中对齐所选单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>左对齐</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>左对齐选定的单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>右对齐</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>右对齐所选单元格内容的</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>顶部对齐</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>顶部对齐所选单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>垂直居中对齐</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>沿所选单元格内容垂直居中对齐</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>导出的电子表格</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>将电子表格导出到 CSV 文件</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>导入电子表格</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>CSV 文件导入到电子表格</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>合并单元格</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>在电子表格中所选单元格合并</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>设置的别名</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>所选单元格的设置的别名</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>拆分单元格</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>将电子表格中的以前合并单元格拆分</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>粗体文本</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>在选定的单元格设置粗体文本</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>斜体文本</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>在选定的单元格设置斜体文本</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>给文本加下划线</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>在选定的单元格设置下划线文本</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>自定义</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>单元格属性</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>颜色(&amp;C)</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>文本</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>背景</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>对齐(&amp;A)</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>水平</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>左视</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>中心</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>右</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>垂直</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>顶视</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>底视</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>样式(&amp;S)</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>粗体</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>斜体</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>下划线</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>显示单位(&amp;D)：</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>单位字符串</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>别名(&amp;A)</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>此单元格的别名</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>所有的 (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>导入文件</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>导出文件</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>单元格内容</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>显示电子表格</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>设置单元格前景色</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>设置电子表格单元格前景色</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>设置单元格的背景色</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>设置电子表格单元背景色</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>黑色</translation>
    </message>
    <message>
      <source>White</source>
      <translation>白色</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>红色</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>暗红色</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>绿色</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>深绿色</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>蓝色</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>深蓝色</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>青色</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>深青色</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>洋红色</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>深洋红色</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>黄色</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>暗黄色</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>灰色</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>暗灰色</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>浅灰色</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>自定义</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>窗体</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>内容(&amp;C)</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>未命名</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>插入行</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>删除行</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>插入列</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>删除列</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>属性...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>创建电子表格</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>创建一个新的电子表格</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>底端对齐</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>底端对齐所选单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>居中对齐</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>居中对齐所选单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>左对齐</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>左对齐选定的单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>右对齐</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>右对齐所选单元格内容的</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>顶部对齐</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>顶部对齐所选单元格的内容</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>垂直居中对齐</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>沿所选单元格内容垂直居中对齐</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>导出的电子表格</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>将电子表格导出到 CSV 文件</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>导入电子表格</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>CSV 文件导入到电子表格</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>合并单元格</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>在电子表格中所选单元格合并</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>设置的别名</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>所选单元格的设置的别名</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>拆分单元格</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>将电子表格中的以前合并单元格拆分</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>粗体文本</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>在选定的单元格设置粗体文本</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>斜体文本</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>在选定的单元格设置斜体文本</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>给文本加下划线</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>在选定的单元格设置下划线文本</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>自定义</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>单元格属性</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>颜色(&amp;C)</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>文本</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>背景</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>对齐(&amp;A)</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>水平</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>左视</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>中心</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>右视</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>垂直</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>俯视</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>底视</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>样式(&amp;S)</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>粗体</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>斜体</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>下划线</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>显示单位(&amp;D)：</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>单位字符串</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>别名(&amp;A)</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>此单元格的别名</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>所有的 (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>导入文件</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>导出文件</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>单元格内容</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>显示电子表格</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>设置单元格前景色</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>设置电子表格单元格前景色</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>设置单元格的背景色</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>设置电子表格单元背景色</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>黑色</translation>
    </message>
    <message>
      <source>White</source>
      <translation>白色</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>红色</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>暗红色</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>绿色</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>深绿色</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>蓝色</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>深蓝色</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>青色</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>深青色</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>洋红色</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>深洋红色</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>黄色</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>暗黄色</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>灰色</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>暗灰色</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>浅灰色</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>自定义</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>窗体</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>内容(&amp;C)</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>未命名</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>插入行</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>删除行</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>插入列</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>删除列</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>属性...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>电子表格</translation>
    </message>
  </context>
</TS>
